@@ -100,8 +100,8 @@ class JAAQLController(BaseJAAQLController):
             return self.model.reset_password(http_inputs)
 
         @self.publish_route('/security-event', DOCUMENTATION__security_event)
-        def security_event(http_inputs: dict, ip_address: str):
+        def security_event(http_inputs: dict):
             if self.is_post():
                 return self.model.check_security_event_key_and_security_event_is_unlocked(http_inputs)
             else:
-                return self.model.finish_security_event(http_inputs, ip_address)
+                return self.model.finish_security_event(http_inputs)
